All platforms.

milia.api.notes


createclj/s

(create note instance-id & [instance-field])

Creates a note for a submission instance given the note and instance-id. Takes an options instance-field argument if note added for specific field.

Creates a note for a submission instance given the note and instance-id.
Takes an options instance-field argument if note added for specific field.
sourceraw docstring

deleteclj/s

(delete note-id)

Deletes a note given a note ID.

Deletes a note given a note ID.
sourceraw docstring

getclj/s

(get note-id)

Returns a note object given a note ID.

Returns a note object given a note ID.
sourceraw docstring

listclj/s

(list & {:keys [instance-id no-cache?]})

Returns all notes. Returns notes for a specific submission if optional instance ID is proviced

Returns all notes. Returns notes for a specific submission if
optional instance ID is proviced
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries