(change-email-address username email-address password)Change the user's email address. This requires a password so that the API can successful update the authentication digest and email can be used to login.
Change the user's email address. This requires a password so that the API can successful update the authentication digest and email can be used to login.
(change-password username current-password new-password)Change user password
Change user password
(expire-temp-token)Expire the user's temporary token.
Expire the user's temporary token.
(get username)Return the user for this username
Return the user for this username
(get-by-email email)Return the users that match this email address
Return the users that match this email address
(get-profiles-for-list-of-users users)Return the profile for the account username or the passed username.
Return the profile for the account username or the passed username.
(google-sheet-authorization code redirect_uri)Send a code to authorize a user to use google sheets
Send a code to authorize a user to use google sheets
(profile username)Return the profile for the account username or the passed username.
Return the profile for the account username or the passed username.
(reset-password new-password token uid & {:keys [suppress-4xx-exceptions?]})(trigger-password-reset-email email reset-url)(trigger-password-reset-email email reset-url reset-subject)Trigger a password reset email to the given email and given return URL. Also takes an optional subject for the email message.
Trigger a password reset email to the given email and given return URL. Also takes an optional subject for the email message.
(update-user-metadata username
metadata
&
{:keys [suppress-4xx-exceptions?]
:or {suppress-4xx-exceptions? nil}})(user & [suppress-4xx-exceptions?])Return the user profile with authentication details.
Return the user profile with authentication details.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |